part of 'application.dart';

class LocaleData {
  final Set<LabelInterface> labels;
  final LiveEvent<LabelInterface> onLabel;
  final List<Locale> supportedLocales;
  final MutableLiveData<Locale?> enforcedLocale;
  final List<LocalizationsDelegate> _localizationDelegates;

  LocaleData({required this.labels, required this.onLabel, Storage? storage, String storageKey = 'locale'})
      : supportedLocales = labels.map((label) => label.locale).toList(growable: false),
        enforcedLocale = storage == null
            ? MutableLiveData()
            : StorageMutableLiveData(
                key: storageKey,
                storage: storage,
                encode: (value) =>
                    value == null ? '' : storage['locale'] = '${value.languageCode}_${value.countryCode}',
                decode: (source) {
                  final code = source.split('_');
                  return code.length == 2 ? Locale(code[0], code[1]) : null;
                }),
        _localizationDelegates = <LocalizationsDelegate>[
          LabelInterfaceDelegate(labels, onLabel.send),
          GlobalMaterialLocalizations.delegate,
          GlobalWidgetsLocalizations.delegate,
          GlobalCupertinoLocalizations.delegate,
        ];

  late Locale _defaultLocale;

  Locale get defaultLocale => _defaultLocale;

  void _initialize() =>
      _defaultLocale = basicLocaleListResolution(WidgetsBinding.instance!.window.locales, supportedLocales);
}
